@@ -2,6 +2,7 @@
 #'
 #' @name igo_dyadic
 #'
+#' @encoding UTF-8
 #' @description
 #' Dyadic version of the data. The unit of observation is a dyad of countries.
 #' It provides a summary of the joint memberships of two countries across IGOs
@@ -24,11 +25,11 @@
 #' datasets. *Journal of Peace Research, 57*(3), 492–503.
 #' \doi{10.1177/0022343319881175}.
 #'
-#' @param country1,country2 A state of vector of states to be compared. It
+#' @param country1,country2 A state or vector of states to be compared. It
 #'   could be any valid name or code of a state as specified on [states2016].
-#' @param year Year to be assessed, an integer or an array of year.
+#' @param year Year to be assessed, an integer or an array of years.
 #' @param ioname Optional. `ioname` or vector of `ioname` corresponding to the
-#'   IGOs to be assessed. If `NULL` (the default), all IGOs would be extracted.
+#'   IGOs to be assessed. If `NULL` (the default), all IGOs will be extracted.
 #'   See codes on [igo_search()].
 #'
 #' @details
@@ -85,7 +86,7 @@
 #'
 #' dplyr::tibble(usa_esp)
 #'
-#' # Using custom parameters
+#' # Using custom arguments
 #' custom <- igo_dyadic(
 #'   country1 = c("France", "Germany"), country2 = c("Sweden", "Austria"),
 #'   year = 1992:1993, ioname = "EU"
@@ -120,7 +121,6 @@ igo_dyadic <- function(country1, country2, year = 1816:2014, ioname = NULL) {
   # Remove 1 to 1 comparisons
   base_df <- base_df[base_df$state1 != base_df$state2, ]
 
-
   if (nrow(base_df) == 0) {
     warning(
       "No different country(ies) found for comparison ",
@@ -133,9 +133,12 @@ igo_dyadic <- function(country1, country2, year = 1816:2014, ioname = NULL) {
 
   iter <- seq_len(nrow(base_df))
 
-  find_v <- lapply(iter, igo_dyadic_single,
+  find_v <- lapply(
+    iter,
+    igo_dyadic_single,
     base_df = base_df,
-    year = year, ioname = ioname
+    year = year,
+    ioname = ioname
   )
 
   # Check results
@@ -144,7 +147,7 @@ igo_dyadic <- function(country1, country2, year = 1816:2014, ioname = NULL) {
   # Clean
   clean <- find_v[!has_results]
   if (length(clean) < 1) {
-    warning("No dyadic results found with the required parameters")
+    warning("No dyadic results found with the required arguments")
     return(invisible(NULL))
   }
 
@@ -174,7 +177,6 @@ igo_dyadic_single <- function(iter, base_df, year, ioname) {
 
   this_iter_df <- base_df[iter, ]
 
-
   # Filter with year
   all_igos <- all_igos[all_igos$year %in% year, ]
 
@@ -188,7 +190,8 @@ igo_dyadic_single <- function(iter, base_df, year, ioname) {
   mat1 <- all_igos[all_igos$state == this_iter_df$state1, ]
   if (nrow(mat1) == 0) {
     message(
-      "Country '", this_iter_df$state1,
+      "Country '",
+      this_iter_df$state1,
       "' was not alive on years selected"
     )
     return(NULL)
@@ -196,7 +199,8 @@ igo_dyadic_single <- function(iter, base_df, year, ioname) {
   mat2 <- all_igos[all_igos$state == this_iter_df$state2, ]
   if (nrow(mat2) == 0) {
     message(
-      "Country '", this_iter_df$state2,
+      "Country '",
+      this_iter_df$state2,
       "' was not alive on years selected"
     )
     return(NULL)
@@ -206,27 +210,19 @@ igo_dyadic_single <- function(iter, base_df, year, ioname) {
   ress <- table(c(mat1$year, mat2$year))
   fyear <- as.numeric(names(ress[ress == 2]))
 
-  mat1_comp <- mat1[mat1$year %in% fyear,
-    tolower(ioname_ext),
-    drop = FALSE
-  ]
-  mat2_comp <- mat2[mat2$year %in% fyear,
-    names(mat1_comp),
-    drop = FALSE
-  ]
-
+  mat1_comp <- mat1[mat1$year %in% fyear, tolower(ioname_ext), drop = FALSE]
+  mat2_comp <- mat2[mat2$year %in% fyear, names(mat1_comp), drop = FALSE]
 
   # Create final matrix and iterate
   mat_res <- matrix(
     data = double(0),
-    nrow = nrow(mat1_comp), ncol = ncol(mat2_comp)
+    nrow = nrow(mat1_comp),
+    ncol = ncol(mat2_comp)
   )
 
-
   n_cols <- seq_len(ncol(mat_res))
   n_rows <- seq_len(nrow(mat_res))
 
-
   for (i in n_rows) {
     for (j in n_cols) {
       vals <- c(mat1_comp[i, j], mat2_comp[i, j])
@@ -260,8 +256,17 @@ igo_dyadic_single <- function(iter, base_df, year, ioname) {
 
   # Re-order columns
   reorder_col <- unique(c(
-    "dyadid", "ccode1", "stateabb1", "statenme1", "state1", "ccode2",
-    "stateabb2", "statenme2", "state2", "year", colnames(end_igos)
+    "dyadid",
+    "ccode1",
+    "stateabb1",
+    "statenme1",
+    "state1",
+    "ccode2",
+    "stateabb2",
+    "statenme2",
+    "state2",
+    "year",
+    colnames(end_igos)
   ))
   end_igos <- end_igos[, reorder_col]
 
