@@ -5,8 +5,8 @@
 #' @description
 #' Extract all the memberships of a state on a specific date.
 #'
-#' @return
-#' A [`data.frame`][data.frame()].
+#' @inherit igo_members source references return
+#' @encoding UTF-8
 #'
 #' @seealso
 #' [igo_year_format3], [igo_search_states()], [states2016].
@@ -16,7 +16,7 @@
 #' @inheritParams igo_search_states
 #'
 #' @param year Year to be assessed, an integer or an array of year. If `NULL`
-#'   the latest year available of the state would be extracted.
+#'   the latest year available of the state will be extracted.
 #' @param status Character or vector with the membership status to be extracted.
 #' See **Details** on [igo_year_format3].
 #'
@@ -48,8 +48,11 @@
 #'   IT$iso3c <- countrycode(IT$ccode, origin = "cown", destination = "iso3c")
 #'   head(IT)
 #' }
-igo_state_membership <- function(state, year = NULL,
-                                 status = "Full Membership") {
+igo_state_membership <- function(
+  state,
+  year = NULL,
+  status = "Full Membership"
+) {
   # Checks
   if (missing(state)) {
     stop("You must enter a value on 'state'")
@@ -77,12 +80,15 @@ igo_state_membership <- function(state, year = NULL,
       "status ",
       paste0("'", status[is.na(checkstatus)], "'", collapse = ", "),
       " not valid. Valid values are ",
-      paste0("'", levls, collapse = "', "), "'"
+      paste0("'", levls, collapse = "', "),
+      "'"
     )
   }
 
   # Find vectorized
-  find_v <- lapply(state_names, igo_state_mmb_single,
+  find_v <- lapply(
+    state_names,
+    igo_state_mmb_single,
     year = year,
     status = status
   )
@@ -93,7 +99,7 @@ igo_state_membership <- function(state, year = NULL,
   # Clean
   clean <- find_v[!has_results]
   if (length(clean) < 1) {
-    warning("No states found with the required parameters")
+    warning("No states found with the required arguments")
     return(invisible(NULL))
   }
 
@@ -126,7 +132,9 @@ igo_state_mmb_single <- function(state_names, year, status) {
   if (nrow(igo_db2) == 0) {
     dates <- range(state_db$year, na.rm = TRUE)
     message(
-      "state '", state_names, "' only alive between ",
+      "state '",
+      state_names,
+      "' only alive between ",
       paste0(dates, collapse = " and ")
     )
     return(NULL)
@@ -135,14 +143,26 @@ igo_state_mmb_single <- function(state_names, year, status) {
   # Get IGO state
   state_igo <- igoR::igo_year_format3
   init_cols <- c(
-    "ioname", "orgname", "year", "longorgname",
-    "political", "social", "economic", state_names
+    "ioname",
+    "orgname",
+    "year",
+    "longorgname",
+    "political",
+    "social",
+    "economic",
+    state_names
   )
 
   state_igo <- state_igo[, tolower(init_cols)]
   colnames(state_igo) <- c(
-    "ioname", "orgname", "year", "longorgname",
-    "political", "social", "economic", "value"
+    "ioname",
+    "orgname",
+    "year",
+    "longorgname",
+    "political",
+    "social",
+    "economic",
+    "value"
   )
   state_igo$category <- igo_recode_igoyear(state_igo$value)
 
@@ -152,8 +172,9 @@ igo_state_mmb_single <- function(state_names, year, status) {
 
   if (nrow(igo_w_year) == 0) {
     message(
-      "No IGOs for state '", state_names,
-      "' with the parameters provided."
+      "No IGOs for state '",
+      state_names,
+      "' with the arguments provided."
     )
     return(NULL)
   }
@@ -163,17 +184,30 @@ igo_state_mmb_single <- function(state_names, year, status) {
   cntriesend <- merge(igo_w_year, df_states)
   # Rearrange columns
   rearcol <- c(
-    "ccode", "stateabb", "statenme", "state",
-    "year", "ioname", "value", "category", "orgname",
-    "longorgname", "political", "social", "economic"
+    "ccode",
+    "stateabb",
+    "statenme",
+    "state",
+    "year",
+    "ioname",
+    "value",
+    "category",
+    "orgname",
+    "longorgname",
+    "political",
+    "social",
+    "economic"
   )
 
   cntriesend <- cntriesend[, rearcol]
 
-  cntriesend <- cntriesend[order(
-    cntriesend$year, cntriesend$category,
-    cntriesend$ioname
-  ), ]
+  cntriesend <- cntriesend[
+    order(
+      cntriesend$year,
+      cntriesend$category,
+      cntriesend$ioname
+    ),
+  ]
 
   rownames(cntriesend) <- NULL
   cntriesend
